import React, { createContext, useState, useContext, useEffect, ReactNode } from 'react';
import { useLocation } from 'wouter';

// Define translation record type
type TranslationRecord = Record<string, string>;

// Define translations inline
const etTranslations = {
  "nav.hinnakiri": "Hinnad",
  "nav.teenused": "Teenused",
  "nav.hinnavordlus": "Võrdlus",
  "nav.meist": "Meist",
  "nav.kontakt": "Kontakt",
  
  "hero.title": "Auto Kaitsekile Paigaldus Tallinnas",
  "hero.subtitle": "Kaitse oma auto kvaliteetse PPF (Paint Protection Film) kilega. Saage kohene hinnapakkumine oma autole!",
  "hero.button1": "Saa kohe hind",
  "hero.button2": "Tutvu teenustega",
  "hero.warranty": "Kuni 10-aastane garantii",
  
  "about.title": "Meist",
  "about.subtitle": "Decords – teie usaldusväärne partner autode kaitsmiseks ja muutmiseks Tallinnas alates 2018. aastast.",
  "about.experience": "Meie kogemus",
  "about.experienceText": "Oleme PPF kiletamise spetsialistid, kes on pühendunud täiuslikkusele igas detailis. Meie meeskond on läbinud rahvusvahelised koolitused ja on sertifitseeritud kasutama uusimaid tehnoloogiaid ja materjale. Igal aastal täiendame oma teadmisi, et pakkuda teile parimat teenust Eesti turul.",
  "about.mission": "Meie missioon",
  "about.missionText": "Soovime muuta auto kaitsmine lihtsaks ja usaldusväärseks. Töötame iga päev selle nimel, et teid teenindada kõrgeimal tasemel, pakkudes kohandatud lahendusi, mis vastavad teie auto vajadustele ja eelistustele. Oleme siin, et säilitada teie auto väärtus ja välimus pikkadeks aastateks.",
  "about.whyUs": "Miks valida meid",
  "about.whyUsText": "Kasutame ainult kõrgeima kvaliteediga materjale maailmatuntud tootjatelt, mis tagab teie auto pikaajalise kaitse ja särava välimuse. Meie stuudio on varustatud täpse lõikamistehnoloogiaga, et tagada ideaalne sobivus iga auto kõverate ja vormidega. Uhkusega pakume 10-aastast garantiid oma tööle ja materjalidele, mis näitab meie pühendumust kvaliteedile.",
  "about.visit": "Külasta meie kaasaegset stuudiot Tallinnas ja veendu ise meie professionaalsuses",
  "about.contact": "Võta meiega ühendust",
  
  "calculator.title": "Arvuta kaitsekile hind",
  "calculator.subtitle": "Vali oma auto mudel ja kaitsekile pakett ning saad kohe hinnapakkumise.",
  "calculator.step1": "1. Vali automudel",
  "calculator.carModel": "Auto mudel",
  "calculator.customModel": "Või sisesta oma mudel",
  "calculator.placeholder": "Nt. Audi Q7 2022",
  "calculator.step2": "2. Vali paketi tüüp",
  "calculator.full": "Täiskere kile",
  "calculator.fullDesc": "Kogu auto kere kaitsekile",
  "calculator.partial": "Osaline kile",
  "calculator.partialDesc": "Kapott, peeglid, tuled, kaitserauad",
  "calculator.riskStandard": "Riskitsoonid \"Standard\"",
  "calculator.riskStandardDesc": "Esiotsa, peeglid, tuled",
  "calculator.riskPremium": "Riskitsoonid \"Premium\"",
  "calculator.riskPremiumDesc": "Esiotsa, peeglid, tuled, lävepakud, pagasiruum",
  "calculator.bumpers": "Kaitserauad",
  "calculator.bumpersDesc": "Esi- ja tagakaitseraua täielik kaitse",
  "calculator.headlights": "Esituled",
  "calculator.headlightsDesc": "Mõlemad esituled, fikseeritud hind 90€",
  "calculator.package": "Vali pakett",
  "calculator.selectModel": "Vali auto mudel",
  "calculator.price": "Hind sisaldab käibemaksu",
  "calculator.requestBtn": "Küsi pakkumist",
  "calculator.whatsappBtn": "WhatsApp konsultatsioon",
  
  "requestForm.title": "Küsi pakkumist",
  "requestForm.subtitle": "Täida vorm ja võtame sinuga peagi ühendust.",
  "requestForm.name": "Nimi",
  "requestForm.email": "E-post",
  "requestForm.phone": "Telefoninumber",
  "requestForm.message": "Lisainfo (valikuline)",
  "requestForm.service": "Valitud teenus:",
  "requestForm.car": "Sinu auto:",
  "requestForm.price": "Hind:",
  "requestForm.submit": "Saada päring",
  "requestForm.sending": "Saatmine...",
  
  "comparison.title": "Kilepakettide võrdlus",
  "comparison.subtitle": "Liiguta auto suuruse liugurit ja võrdle erinevate kaitsekile variantide hindu. Vali oma autole sobiv lahendus.",
  "comparison.carSize": "Auto suurus",
  "comparison.small": "Väike",
  "comparison.medium": "Keskmine",
  "comparison.large": "Suur",
  "comparison.sliderHint": "* Liiguta liugurit vastavalt oma auto suurusele täpse hinna saamiseks",
  "comparison.popular": "Populaarne",
  "comparison.taxIncluded": "Hind sisaldab käibemaksu",
  "comparison.estimatedTime": "Hinnanguline aeg:",
  "comparison.askBtn": "Küsi nõu",
  
  "services.title": "PPF kaitsekile paketid",
  "services.subtitle": "Meie auto kaitsekile paketid kaitsevad auto värvkatet kivitäkkete, kriimustuste ja teekahjustuste eest, säilitades teie auto väärtust.",
  "services.learnBtn": "Loe lähemalt",
  "services.features": "Omadused",
  "services.benefits": "Eelised",
  
  "benefits.title": "PPF kaitsekile eelised",
  "benefits.subtitle": "Miks valida auto kaitsekile (PPF) - Paint Protection Film?",
  
  "process.title": "Kuidas paigaldamine toimub?",
  "process.subtitle": "Meie kiletamise protsess on professionaalne ja põhjalik",
  "process.step1": "Konsultatsioon",
  "process.step1Desc": "Arutame teie vajadusi ja soovitame parimat lahendust",
  "process.step2": "Ettevalmistus",
  "process.step2Desc": "Auto pind puhastatakse ja valmistatakse põhjalikult ette",
  "process.step3": "Kiletamine",
  "process.step3Desc": "Professionaalne paigaldus millimeetrise täpsusega",
  "process.step4": "Kvaliteedikontroll",
  "process.step4Desc": "Põhjalik ülevaatus pärast paigaldust",
  
  "appointment.title": "Broneeri konsultatsioon",
  "appointment.subtitle": "Vali sobiv aeg ja päev konsultatsiooniks",
  "appointment.timeSlots": "Saadaolevad ajad",
  "appointment.noSlots": "Sellel päeval pole vabu aegu",
  "appointment.formTitle": "Täida järgmised andmed",
  "appointment.book": "Broneeri aeg",
  
  "whatsapp.message": "Tere! Soovin konsultatsiooni PPF kaitsekile paigaldamise kohta. Kas saate mind aidata?",
  "whatsapp.priceMessage": "Tere! Soovin rohkem infot {0} paketi kohta. Auto suurus: {1}. Hinnapakkumine: {2}€",
  "whatsapp.consultationBtn": "Kiire konsultatsioon",
  "whatsapp.floatingBtn": "Küsi konsultatsiooni",
  "whatsapp.footerBtn": "Küsi WhatsAppis",
  
  "footer.description": "Decords pakub professionaalseid auto kaitsekile teenuseid, et hoida teie auto kaitstud ja ideaalses seisus.",
  "footer.quickLinks": "Kiirlingid",
  "footer.contact": "Kontakt",
  "footer.rights": "Kõik õigused kaitstud.",
  "footer.privacy": "Privaatsuspoliitika",
  "footer.terms": "Kasutustingimused",
  
  "language.et": "EE",
  "language.ru": "RU"
};

const ruTranslations = {
  "nav.hinnakiri": "Цены",
  "nav.teenused": "Услуги",
  "nav.hinnavordlus": "Сравнение",
  "nav.meist": "О нас",
  "nav.kontakt": "Контакт",
  
  "hero.title": "Антигравийная защитная пленка PPF для автомобилей в Таллинне",
  "hero.subtitle": "Профессиональная антигравийная защита кузова автомобиля премиальной пленкой PPF. Защита от сколов, царапин и дорожных повреждений с гарантией до 10 лет!",
  "hero.button1": "Рассчитать стоимость",
  "hero.button2": "Варианты защиты",
  "hero.warranty": "Гарантия качества до 10 лет",
  
  "about.title": "О нас",
  "about.subtitle": "Decords – ваш надежный партнер по защите и преображению автомобилей в Таллинне с 2018 года.",
  "about.experience": "Наш опыт",
  "about.experienceText": "Мы – специалисты по оклейке PPF пленкой, стремящиеся к совершенству в каждой детали. Наша команда прошла международное обучение и сертифицирована для работы с новейшими технологиями и материалами. Ежегодно мы обновляем свои знания, чтобы предлагать вам лучший сервис на эстонском рынке.",
  "about.mission": "Наша миссия",
  "about.missionText": "Мы стремимся сделать защиту автомобиля простой и надежной. Каждый день мы работаем над тем, чтобы обслуживать вас на высочайшем уровне, предлагая индивидуальные решения, отвечающие потребностям и предпочтениям вашего автомобиля. Мы здесь, чтобы сохранить ценность и внешний вид вашего автомобиля на долгие годы.",
  "about.whyUs": "Почему выбирают нас",
  "about.whyUsText": "Мы используем только материалы высочайшего качества от всемирно известных производителей, что обеспечивает долговременную защиту и сияющий внешний вид вашего автомобиля. Наша студия оснащена точной технологией резки, гарантирующей идеальное соответствие изгибам и формам любого автомобиля. С гордостью предоставляем 10-летнюю гарантию на нашу работу и материалы, что демонстрирует нашу приверженность качеству.",
  "about.visit": "Посетите нашу современную студию в Таллинне и убедитесь в нашем профессионализме лично",
  "about.contact": "Связаться с нами",
  
  "calculator.title": "Онлайн-калькулятор стоимости антигравийной защиты",
  "calculator.subtitle": "Выберите модель вашего автомобиля и комплект антигравийной защитной пленки PPF для моментального расчета стоимости.",
  "calculator.step1": "1. Выберите марку и модель авто",
  "calculator.carModel": "Марка и модель автомобиля",
  "calculator.customModel": "Или введите вашу модель вручную",
  "calculator.placeholder": "Напр. Audi Q7 2022, BMW X5, Mercedes GLE",
  "calculator.step2": "2. Выберите вариант защиты кузова",
  "calculator.full": "Полная антигравийная защита кузова",
  "calculator.fullDesc": "Комплексная защита всего кузова премиальной пленкой PPF",
  "calculator.partial": "Частичная защита кузова",
  "calculator.partialDesc": "Капот, зеркала, фары, бамперы и другие зоны риска",
  "calculator.riskStandard": "Защита зон риска \"Стандарт\"",
  "calculator.riskStandardDesc": "Передний бампер, капот, зеркала, фары",
  "calculator.riskPremium": "Защита зон риска \"Премиум\"",
  "calculator.riskPremiumDesc": "Передний бампер, капот, зеркала, фары, пороги, задний бампер",
  "calculator.bumpers": "Антигравийная защита бамперов",
  "calculator.bumpersDesc": "Полная защита переднего и заднего бамперов от сколов и царапин",
  "calculator.headlights": "Защита фар от повреждений",
  "calculator.headlightsDesc": "Защитная пленка на обе фары, фиксированная цена 90€",
  "calculator.package": "Выберите комплект защиты",
  "calculator.selectModel": "Выберите модель автомобиля",
  "calculator.price": "Итоговая цена с учетом НДС",
  "calculator.requestBtn": "Получить персональное предложение",
  "calculator.whatsappBtn": "Консультация в WhatsApp",
  
  "requestForm.title": "Получить персональное предложение по защите вашего автомобиля",
  "requestForm.subtitle": "Заполните форму для получения детального коммерческого предложения с точной стоимостью и сроками. Мы свяжемся с вами в течение 2 часов в рабочее время.",
  "requestForm.name": "Ваше имя",
  "requestForm.email": "Электронная почта",
  "requestForm.phone": "Контактный телефон",
  "requestForm.message": "Дополнительная информация или вопросы (опционально)",
  "requestForm.service": "Выбранный комплект защиты:",
  "requestForm.car": "Марка и модель вашего автомобиля:",
  "requestForm.price": "Предварительная стоимость:",
  "requestForm.submit": "Отправить запрос на расчет",
  "requestForm.sending": "Отправка запроса...",
  
  "comparison.title": "Сравнение вариантов защиты автомобиля пленкой PPF",
  "comparison.subtitle": "Используйте интерактивный ползунок для выбора размера вашего автомобиля и мгновенно сравнивайте стоимость различных комплектов антигравийной защиты. Выберите оптимальное соотношение цены и защиты для вашего автомобиля.",
  "comparison.carSize": "Класс и размер автомобиля",
  "comparison.small": "Малый (A, B класс)",
  "comparison.medium": "Средний (C, D класс)",
  "comparison.large": "Большой (E, F, SUV)",
  "comparison.sliderHint": "* Передвиньте ползунок в соответствии с классом и размером вашего автомобиля для получения точной цены",
  "comparison.popular": "Самый популярный",
  "comparison.taxIncluded": "Цена включает НДС 20%",
  "comparison.estimatedTime": "Время установки:",
  "comparison.askBtn": "Получить бесплатную консультацию",
  
  "services.title": "Премиальные комплекты защитной пленки PPF",
  "services.subtitle": "Наши профессиональные комплекты антигравийной защитной пленки PPF надежно защищают лакокрасочное покрытие вашего автомобиля от сколов, царапин, воздействия песка, соли и химических реагентов на дорогах. Сохраните первоначальный вид и стоимость вашего автомобиля на долгие годы.",
  "services.learnBtn": "Подробнее о защите",
  "services.features": "Технические характеристики",
  "services.benefits": "Ключевые преимущества",
  
  "benefits.title": "7 главных преимуществ антигравийной пленки PPF",
  "benefits.subtitle": "Почему тысячи владельцев автомобилей в Таллинне выбирают защитную пленку PPF (Paint Protection Film) для своих авто?",
  
  "process.title": "Как происходит установка защитной пленки?",
  "process.subtitle": "Наш процесс профессиональной оклейки антигравийной пленкой PPF выполняется опытными мастерами с использованием премиальных материалов",
  "process.step1": "Бесплатная консультация",
  "process.step1Desc": "Детально обсудим ваши потребности и подберем оптимальный вариант защиты для вашего автомобиля",
  "process.step2": "Тщательная подготовка поверхности",
  "process.step2Desc": "Профессиональная очистка, обезжиривание и подготовка поверхности кузова перед оклейкой",
  "process.step3": "Прецизионная установка пленки",
  "process.step3Desc": "Точная компьютерная раскройка и профессиональное нанесение с идеальной подгонкой каждого элемента",
  "process.step4": "Многоуровневый контроль качества",
  "process.step4Desc": "Тщательная проверка всех оклеенных элементов и финальная полировка для безупречного результата",
  
  "appointment.title": "Записаться на бесплатную консультацию по защите автомобиля",
  "appointment.subtitle": "Выберите удобную дату и время для детальной консультации с нашим специалистом по антигравийной защите автомобиля",
  "appointment.timeSlots": "Доступное время для консультации",
  "appointment.noSlots": "На выбранную дату нет свободного времени. Пожалуйста, выберите другой день или свяжитесь с нами по WhatsApp.",
  "appointment.formTitle": "Введите ваши контактные данные для записи",
  "appointment.book": "Забронировать бесплатную консультацию",
  
  "whatsapp.message": "Здравствуйте! Интересует профессиональная антигравийная защита автомобиля пленкой PPF. Можете проконсультировать по вариантам и стоимости?",
  "whatsapp.priceMessage": "Здравствуйте! Интересует комплект защиты \"{0}\" для автомобиля класса \"{1}\". Расчетная стоимость: {2}€. Хотел бы узнать подробнее об этом варианте защиты.",
  "whatsapp.consultationBtn": "Быстрая консультация в WhatsApp",
  "whatsapp.floatingBtn": "Получить консультацию в WhatsApp",
  "whatsapp.footerBtn": "Задать вопрос в WhatsApp",
  
  "footer.description": "Компания Decords предлагает профессиональные услуги по защите автомобилей премиальной антигравийной пленкой PPF в Таллинне. Мы используем только сертифицированные материалы ведущих производителей и гарантируем высочайшее качество работы.",
  "footer.quickLinks": "Полезные ссылки",
  "footer.contact": "Наши контакты",
  "footer.rights": "© Decords OÜ 2024. Все права защищены.",
  "footer.privacy": "Политика конфиденциальности",
  "footer.terms": "Условия использования сайта",
  
  "language.et": "EE",
  "language.ru": "RU"
};

export type Language = 'et' | 'ru';

interface LanguageContextType {
  language: Language;
  setLanguage: (lang: Language) => void;
  t: (key: string) => string;
}

const LanguageContext = createContext<LanguageContextType | undefined>(undefined);

interface LanguageProviderProps {
  children: ReactNode;
}

export const LanguageProvider: React.FC<LanguageProviderProps> = ({ children }) => {
  const [location, navigate] = useLocation();
  
  const getInitialLanguage = (): Language => {
    // Determine language from URL path
    if (location.startsWith('/ru')) {
      return 'ru';
    }
    
    // Otherwise check stored language preference or browser preference
    const storedLanguage = localStorage.getItem('language') as Language;
    if (storedLanguage && (storedLanguage === 'et' || storedLanguage === 'ru')) {
      return storedLanguage;
    }
    
    // Try to get browser language
    const browserLang = navigator.language.split('-')[0];
    if (browserLang === 'ru') {
      return 'ru';
    }
    
    // Default to Estonian
    return 'et';
  };

  const [language, setLanguageState] = useState<Language>(getInitialLanguage);

  // Translation function
  const t = (key: string): string => {
    const translations = language === 'et' ? etTranslations : ruTranslations;
    console.log('Current language:', language, 'Looking for key:', key);
    
    const translation = translations[key as keyof typeof translations];
    const finalResult = translation || key;
    console.log('Translation result:', finalResult);
    return finalResult;
  };

  const setLanguage = (lang: Language) => {
    console.log('Setting language to:', lang);
    setLanguageState(lang);
    localStorage.setItem('language', lang);
    
    // Update URL to match language
    if (lang === 'ru' && !location.startsWith('/ru')) {
      navigate('/ru' + (location === '/' ? '' : location));
    } else if (lang === 'et' && location.startsWith('/ru')) {
      navigate(location.replace(/^\/ru/, '') || '/');
    }
    
    // Set HTML lang attribute for SEO
    document.documentElement.lang = lang;
    
    // Set hreflang tags for SEO
    updateHreflangTags(lang, location);
  };
  
  // Update hreflang tags for SEO
  const updateHreflangTags = (currentLang: Language, currentPath: string) => {
    // Remove existing hreflang tags
    document.querySelectorAll('link[rel="alternate"][hreflang]').forEach(el => el.remove());
    
    // Create base URL
    const baseUrl = window.location.origin;
    
    // Strip language prefix from path if present
    let pathWithoutLang = currentPath;
    if (pathWithoutLang.startsWith('/ru')) {
      pathWithoutLang = pathWithoutLang.substring(3) || '/';
    }
    
    // Add hreflang tags
    const etUrl = baseUrl + (pathWithoutLang === '/' ? '' : pathWithoutLang);
    const ruUrl = baseUrl + '/ru' + (pathWithoutLang === '/' ? '' : pathWithoutLang);
    
    // Create and append Estonian hreflang
    const etLink = document.createElement('link');
    etLink.rel = 'alternate';
    etLink.hreflang = 'et';
    etLink.href = etUrl;
    document.head.appendChild(etLink);
    
    // Create and append Russian hreflang
    const ruLink = document.createElement('link');
    ruLink.rel = 'alternate';
    ruLink.hreflang = 'ru';
    ruLink.href = ruUrl;
    document.head.appendChild(ruLink);
    
    // Create and append x-default hreflang (pointing to Estonian)
    const defaultLink = document.createElement('link');
    defaultLink.rel = 'alternate';
    defaultLink.hreflang = 'x-default';
    defaultLink.href = etUrl;
    document.head.appendChild(defaultLink);
  };
  
  // Set initial language and hreflang tags on mount
  useEffect(() => {
    const lang = getInitialLanguage();
    setLanguageState(lang);
    document.documentElement.lang = lang;
    updateHreflangTags(lang, location);
  }, []);
  
  // Update when location changes
  useEffect(() => {
    const lang = getInitialLanguage();
    if (lang !== language) {
      setLanguageState(lang);
      document.documentElement.lang = lang;
    }
    updateHreflangTags(language, location);
  }, [location]);

  return (
    <LanguageContext.Provider value={{ language, setLanguage, t }}>
      {children}
    </LanguageContext.Provider>
  );
};

export const useLanguage = (): LanguageContextType => {
  const context = useContext(LanguageContext);
  if (!context) {
    throw new Error('useLanguage must be used within a LanguageProvider');
  }
  return context;
};